Get an sspLNIRT.object from the precomputed sspLNIRT data
Source:R/fct_get_sspLNIRT.R
get_sspLNIRT.RdThe function gets the sspLNIRT object from the sspLNIRT data tibble, containing the minimum sample size to reach the threshold of root mean squared errors (RMSE) of estimated parameters. The sspLNIRT data was precomputed using `optim_sample`. The RMSE is based on simulated data under the Joint Hierarchical Model using a 2-pl normal ogive model for response accuracy and a 3-pl log-normal model for response time.
Arguments
- thresh
Numeric vector. The desired RMSE threshold(s) of the target parameter(s) to be achieved.
- out.par
Character vector. The name(s) of the target parameter(s) for the threshold(s).
- K
Integer. The test length.
- mu.alpha
Numeric. The mean of the discrimination parameter alpha.
- meanlog.sigma2
Numeric. The meanlog of sigma2.
- rho
Numeric. The correlation between theta and zeta.