Skip to contents

The function plots the root mean squared error (RMSE) or bias across values of the true parameter. For sspLNIRT.objects from optim_sample(), get_sspLNIRT(), or comp_rmse(), the function uses the data at the minimum N, or, if the optimization stopped due to N being outside the specified range, at the respective bound.

Usage

plot_estimation(object, pars = "item", y.val = "rmse", n.bins = 30)

Arguments

object

Object. sspLNIRT.object from optim_sample(), get_sspLNIRT(), or comp_rmse().

pars

String. Either "item" or "person" for which parameters to plot.

y.val

String. Either "rmse" or "bias" for the y-axis.

n.bins

Integer (optional). Number of bins used to aggregate by sim.val within par.

Value

A ggplot object.

Examples

 if (FALSE) { # \dontrun{
   plot_estimation(object = test.optim.sample, pars = "item")
} # }