The function plots the root mean squared error (RMSE) or bias across values of the true parameter. For sspLNIRT.objects from optim_sample(), get_sspLNIRT(), or comp_rmse(), the
function uses the data at the minimum N, or, if the optimization stopped due to N being outside the specified range, at the respective bound.
Arguments
- object
Object. sspLNIRT.object from
optim_sample(),get_sspLNIRT(), orcomp_rmse().- pars
String. Either "item" or "person" for which parameters to plot.
- y.val
String. Either "rmse" or "bias" for the y-axis.
- n.bins
Integer (optional). Number of bins used to aggregate by sim.val within par.